@@ -14,8 +14,11 @@ from conans.util.files import rmdir, set_dirty, is_dirty, clean_dirty, mkdir
 
 def get_scm(conanfile, src_folder):
     data = getattr(conanfile, "scm", None)
-    if data is not None:
+    if data is not None and isinstance(data, dict):
         return SCM(data, src_folder)
+    else:
+        # not an instance of dict or None, skip SCM feature.
+        pass
 
 
 def complete_recipe_sources(remote_manager, client_cache, registry, conanfile, conan_reference):
