@@ -54,6 +54,22 @@ class CMakeTest(unittest.TestCase):
             self.assertEqual("FOLDER: ${CONAN_MYPKG_ROOT}",
                              load(os.path.join(folder, "sub", "file3.cmake")))
 
+    def partial_build_test(self):
+        conan_file = ConanFileMock()
+        conan_file.settings = Settings()
+        conan_file.should_configure = False
+        conan_file.should_build = False
+        conan_file.should_install = False
+        cmake = CMake(conan_file, generator="Unix Makefiles")
+        cmake.configure()
+        self.assertIsNone(conan_file.command)
+        cmake.build()
+        self.assertIsNone(conan_file.command)
+        cmake.install()
+        self.assertIsNone(conan_file.command)
+        conan_file.name = None
+        cmake.patch_config_paths()
+
     def cmake_generator_test(self):
         conan_file = ConanFileMock()
         conan_file.settings = Settings()
@@ -61,6 +77,61 @@ class CMakeTest(unittest.TestCase):
             cmake = CMake(conan_file)
             self.assertIn('-G "My CMake Generator"', cmake.command_line)
 
+    def cmake_fpic_test(self):
+        settings = Settings.loads(default_settings_yml)
+        settings.os = "Linux"
+        settings.compiler = "gcc"
+        settings.compiler.version = "6.3"
+        settings.arch = "x86"
+
+        def assert_fpic(the_settings, input_shared, input_fpic, expected_option):
+            options = []
+            values = {}
+            if input_shared is not None:
+                options.append('"shared": [True, False]')
+                values["shared"] = input_shared
+            if input_fpic is not None:
+                options.append('"fPIC": [True, False]')
+                values["fPIC"] = input_fpic
+
+            conan_file = ConanFileMock(options='{%s}' % ", ".join(options),
+                                       options_values=values)
+            conan_file.settings = the_settings
+            cmake = CMake(conan_file)
+            cmake.configure()
+            if expected_option is not None:
+                self.assertEquals(cmake.definitions["CONAN_CMAKE_POSITION_INDEPENDENT_CODE"],
+                                  expected_option)
+            else:
+                self.assertNotIn("CONAN_CMAKE_POSITION_INDEPENDENT_CODE", cmake.definitions)
+
+        # Test shared=False and fpic=False
+        assert_fpic(settings, input_shared=False, input_fpic=False, expected_option="OFF")
+
+        # Test shared=True and fpic=False
+        assert_fpic(settings, input_shared=True, input_fpic=False, expected_option="ON")
+
+        # Test shared=True and fpic=True
+        assert_fpic(settings, input_shared=True, input_fpic=True, expected_option="ON")
+
+        # Test shared not defined and fpic=True
+        assert_fpic(settings, input_shared=None, input_fpic=True, expected_option="ON")
+
+        # Test shared not defined and fpic not defined
+        assert_fpic(settings, input_shared=None, input_fpic=None, expected_option=None)
+
+        # Test shared True and fpic not defined
+        assert_fpic(settings, input_shared=True, input_fpic=None, expected_option=None)
+
+        # Test nothing in Windows
+        settings = Settings.loads(default_settings_yml)
+        settings.os = "Windows"
+        settings.compiler = "Visual Studio"
+        settings.compiler.version = "15"
+        settings.arch = "x86_64"
+
+        assert_fpic(settings, input_shared=True, input_fpic=True, expected_option=None)
+
     def cmake_make_program_test(self):
         settings = Settings.loads(default_settings_yml)
         settings.os = "Linux"
@@ -102,59 +173,60 @@ class CMakeTest(unittest.TestCase):
         conan_file.settings = settings
         conan_file.source_folder = os.path.join(self.tempdir, "my_cache_source_folder")
         conan_file.build_folder = os.path.join(self.tempdir, "my_cache_build_folder")
-        cmake = CMake(conan_file)
-        cmake.configure(source_dir="../subdir", build_dir="build")
-        linux_stuff = '-DCMAKE_SYSTEM_NAME="Linux" ' \
-                      '-DCMAKE_SYSROOT="/path/to/sysroot" ' if platform.system() != "Linux" else ""
-        generator = "MinGW Makefiles" if platform.system() == "Windows" else "Unix Makefiles"
-        base_cmd = ' && cmake -G "%s" -DCMAKE_BUILD_TYPE="Release" %s' \
-                   '-DCONAN_EXPORTED="1" -DCONAN_COMPILER="gcc" ' \
-                   '-DCONAN_COMPILER_VERSION="6.3" ' \
-                   '-DCONAN_CXX_FLAGS="-m32" -DCONAN_SHARED_LINKER_FLAGS="-m32" ' \
-                   '-DCONAN_C_FLAGS="-m32" -Wno-dev ' % (generator, linux_stuff)
-        build_expected = quote_var("build")
-        source_expected = quote_var("../subdir")
+        with tools.chdir(self.tempdir):
+            cmake = CMake(conan_file)
+            cmake.configure(source_dir="../subdir", build_dir="build")
+            linux_stuff = '-DCMAKE_SYSTEM_NAME="Linux" ' \
+                          '-DCMAKE_SYSROOT="/path/to/sysroot" ' if platform.system() != "Linux" else ""
+            generator = "MinGW Makefiles" if platform.system() == "Windows" else "Unix Makefiles"
+            base_cmd = ' && cmake -G "%s" -DCMAKE_BUILD_TYPE="Release" %s' \
+                       '-DCONAN_EXPORTED="1" -DCONAN_COMPILER="gcc" ' \
+                       '-DCONAN_COMPILER_VERSION="6.3" ' \
+                       '-DCONAN_CXX_FLAGS="-m32" -DCONAN_SHARED_LINKER_FLAGS="-m32" ' \
+                       '-DCONAN_C_FLAGS="-m32" -Wno-dev ' % (generator, linux_stuff)
+            build_expected = quote_var("build")
+            source_expected = quote_var("../subdir")
 
-        self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
+            self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
 
-        cmake.configure(build_dir="build")
-        build_expected = quote_var("build")
-        source_expected = quote_var(os.path.join(self.tempdir, "my_cache_source_folder"))
-        self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
+            cmake.configure(build_dir="build")
+            build_expected = quote_var("build")
+            source_expected = quote_var(os.path.join(self.tempdir, "my_cache_source_folder"))
+            self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
 
-        cmake.configure()
-        build_expected = quote_var(os.path.join(self.tempdir, "my_cache_build_folder"))
-        source_expected = quote_var(os.path.join(self.tempdir, "my_cache_source_folder"))
-        self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
+            cmake.configure()
+            build_expected = quote_var(os.path.join(self.tempdir, "my_cache_build_folder"))
+            source_expected = quote_var(os.path.join(self.tempdir, "my_cache_source_folder"))
+            self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
 
-        cmake.configure(source_folder="source", build_folder="build")
-        build_expected = quote_var(os.path.join(os.path.join(self.tempdir, "my_cache_build_folder", "build")))
-        source_expected = quote_var(os.path.join(os.path.join(self.tempdir, "my_cache_source_folder", "source")))
-        self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
+            cmake.configure(source_folder="source", build_folder="build")
+            build_expected = quote_var(os.path.join(os.path.join(self.tempdir, "my_cache_build_folder", "build")))
+            source_expected = quote_var(os.path.join(os.path.join(self.tempdir, "my_cache_source_folder", "source")))
+            self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
 
-        conan_file.in_local_cache = True
-        cmake.configure(source_folder="source", build_folder="build",
-                        cache_build_folder="rel_only_cache")
-        build_expected = quote_var(os.path.join(self.tempdir, "my_cache_build_folder", "rel_only_cache"))
-        source_expected = quote_var(os.path.join(self.tempdir, "my_cache_source_folder", "source"))
-        self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
+            conan_file.in_local_cache = True
+            cmake.configure(source_folder="source", build_folder="build",
+                            cache_build_folder="rel_only_cache")
+            build_expected = quote_var(os.path.join(self.tempdir, "my_cache_build_folder", "rel_only_cache"))
+            source_expected = quote_var(os.path.join(self.tempdir, "my_cache_source_folder", "source"))
+            self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
 
-        conan_file.in_local_cache = False
-        cmake.configure(source_folder="source", build_folder="build",
-                        cache_build_folder="rel_only_cache")
-        build_expected = quote_var(os.path.join(self.tempdir, "my_cache_build_folder", "build"))
-        source_expected = quote_var(os.path.join(self.tempdir, "my_cache_source_folder", "source"))
-        self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
+            conan_file.in_local_cache = False
+            cmake.configure(source_folder="source", build_folder="build",
+                            cache_build_folder="rel_only_cache")
+            build_expected = quote_var(os.path.join(self.tempdir, "my_cache_build_folder", "build"))
+            source_expected = quote_var(os.path.join(self.tempdir, "my_cache_source_folder", "source"))
+            self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
 
-        conan_file.in_local_cache = True
-        cmake.configure(build_dir="build", cache_build_folder="rel_only_cache")
-        build_expected = quote_var(os.path.join(self.tempdir, "my_cache_build_folder", "rel_only_cache"))
-        source_expected = quote_var(os.path.join(self.tempdir, "my_cache_source_folder"))
-        self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
+            conan_file.in_local_cache = True
+            cmake.configure(build_dir="build", cache_build_folder="rel_only_cache")
+            build_expected = quote_var(os.path.join(self.tempdir, "my_cache_build_folder", "rel_only_cache"))
+            source_expected = quote_var(os.path.join(self.tempdir, "my_cache_source_folder"))
+            self.assertEquals(conan_file.command, 'cd %s' % build_expected + base_cmd + source_expected)
 
-        # Raise mixing
-        with self.assertRaisesRegexp(ConanException, "Use 'build_folder'/'source_folder'"):
-            cmake.configure(source_folder="source", build_dir="build")
+            # Raise mixing
+            with self.assertRaisesRegexp(ConanException, "Use 'build_folder'/'source_folder'"):
+                cmake.configure(source_folder="source", build_dir="build")
 
     def build_type_ovewrite_test(self):
         settings = Settings.loads(default_settings_yml)
@@ -366,7 +438,6 @@ build_type: [ Release]
                          cmake.command_line)
 
     def test_sysroot(self):
-
         settings = Settings.loads(default_settings_yml)
         conan_file = ConanFileMock()
         conan_file.settings = settings
@@ -376,12 +447,15 @@ build_type: [ Release]
         settings.arch = "x86"
         settings.os = "Windows"
         cmake = CMake(conan_file)
-        self.assertNotIn("-DCMAKE_SYSROOT=", cmake.flags) if platform.system() == "Windows" else ""
+        if platform.system() == "Windows":
+            self.assertNotIn("-DCMAKE_SYSROOT=", cmake.flags)
 
-        # Now activate cross build and check sysroot
-        with(tools.environment_append({"CONAN_CMAKE_SYSTEM_NAME": "Android"})):
+        # Now activate cross build and check sysroot and system processor
+        with(tools.environment_append({"CONAN_CMAKE_SYSTEM_NAME": "Android",
+                                       "CONAN_CMAKE_SYSTEM_PROCESSOR": "somevalue"})):
             cmake = CMake(conan_file)
             self.assertEquals(cmake.definitions["CMAKE_SYSROOT"], "/path/to/sysroot")
+            self.assertEquals(cmake.definitions["CMAKE_SYSTEM_PROCESSOR"], "somevalue")
 
     def test_deprecated_behaviour(self):
         """"Remove when deprecate the old settings parameter to CMake and
@@ -554,7 +628,7 @@ build_type: [ Release]
         settings = Settings.loads(default_settings_yml)
         settings.os = "Windows"
         settings.compiler = "Visual Studio"
-        settings.compiler.version = "12"
+        settings.compiler.version = "14"
         settings.compiler.runtime = "MDd"
         settings.arch = "x86"
         settings.build_type = None
@@ -614,6 +688,38 @@ build_type: [ Release]
         cmake.configure()
         self.assertNotIn(self.tempdir, conanfile.path)
 
+    def test_pkg_config_path(self):
+        conanfile = ConanFileMock()
+        conanfile.generators = ["pkg_config"]
+        conanfile.install_folder = "/my_install/folder/"
+        settings = Settings.loads(default_settings_yml)
+        settings.os = "Windows"
+        settings.compiler = "Visual Studio"
+        settings.compiler.version = "12"
+        settings.arch = "x86"
+        conanfile.settings = settings
+        cmake = CMake(conanfile)
+        cmake.configure()
+        self.assertEquals(conanfile.captured_env["PKG_CONFIG_PATH"], "/my_install/folder/")
+
+        conanfile.generators = []
+        cmake = CMake(conanfile)
+        cmake.configure()
+        self.assertNotIn("PKG_CONFIG_PATH", conanfile.captured_env)
+
+        cmake = CMake(conanfile)
+        cmake.configure(pkg_config_paths=["reldir1", "/abspath2/to/other"])
+        self.assertEquals(conanfile.captured_env["PKG_CONFIG_PATH"],
+                          os.path.pathsep.join(["/my_install/folder/reldir1",
+                                                "/abspath2/to/other"]))
+
+        # If there is already a PKG_CONFIG_PATH do not set it
+        conanfile.generators = ["pkg_config"]
+        cmake = CMake(conanfile)
+        with tools.environment_append({"PKG_CONFIG_PATH": "do_not_mess_with_this"}):
+            cmake.configure()
+            self.assertEquals(conanfile.captured_env["PKG_CONFIG_PATH"], "do_not_mess_with_this")
+
     def test_shared(self):
         settings = Settings.loads(default_settings_yml)
         settings.os = "Windows"
@@ -700,6 +806,49 @@ build_type: [ Release]
         cmake = CMake(conan_file)
         self.assertIn('-T "v140"', cmake.command_line)
 
+    def test_missing_settings(self):
+        def instance_with_os_build(os_build):
+            settings = Settings.loads(default_settings_yml)
+            settings.os_build = os_build
+            conan_file = ConanFileMock()
+            conan_file.settings = settings
+            return CMake(conan_file)
+
+        cmake = instance_with_os_build("Linux")
+        self.assertEquals(cmake.generator, "Unix Makefiles")
+
+        cmake = instance_with_os_build("Macos")
+        self.assertEquals(cmake.generator, "Unix Makefiles")
+
+        with self.assertRaisesRegexp(ConanException, "You must specify compiler, "
+                                                     "compiler.version and arch"):
+            instance_with_os_build("Windows")
+
+        with tools.environment_append({"CONAN_CMAKE_GENERATOR": "MyCoolGenerator"}):
+            cmake = instance_with_os_build("Windows")
+            self.assertEquals(cmake.generator, "MyCoolGenerator")
+
+    def test_cmake_system_version_android(self):
+        with tools.environment_append({"CONAN_CMAKE_SYSTEM_NAME": "SomeSystem",
+                                       "CONAN_CMAKE_GENERATOR": "SomeGenerator"}):
+            settings = Settings.loads(default_settings_yml)
+            settings.os = "WindowsStore"
+            settings.os.version = "8.1"
+
+            conan_file = ConanFileMock()
+            conan_file.settings = settings
+            cmake = CMake(conan_file)
+            self.assertEquals(cmake.definitions["CMAKE_SYSTEM_VERSION"], "8.1")
+
+            settings = Settings.loads(default_settings_yml)
+            settings.os = "Android"
+            settings.os.api_level = "32"
+
+            conan_file = ConanFileMock()
+            conan_file.settings = settings
+            cmake = CMake(conan_file)
+            self.assertEquals(cmake.definitions["CMAKE_SYSTEM_VERSION"], "32")
+
     @staticmethod
     def scape(args):
         pattern = "%s" if sys.platform == "win32" else r"'%s'"
@@ -707,19 +856,29 @@ build_type: [ Release]
 
 
 class ConanFileMock(ConanFile):
-    def __init__(self, shared=None):
+    def __init__(self, shared=None, options=None, options_values=None):
+        options = options or ""
         self.command = None
         self.path = None
         self.source_folder = self.build_folder = "."
         self.settings = None
-        self.options = Options(PackageOptions.loads(""))
+        self.options = Options(PackageOptions.loads(options))
+        if options_values:
+            for var, value in options_values.items():
+                self.options._data[var] = value
         self.deps_cpp_info = namedtuple("deps_cpp_info", "sysroot")("/path/to/sysroot")
         self.output = TestBufferConanOutput()
         self.in_local_cache = False
         self.install_folder = "myinstallfolder"
         if shared is not None:
             self.options = namedtuple("options", "shared")(shared)
+        self.should_configure = True
+        self.should_build = True
+        self.should_install = True
+        self.generators = []
+        self.captured_env = {}
 
     def run(self, command):
         self.command = command
         self.path = os.environ["PATH"]
+        self.captured_env = {key: value for key, value in os.environ.items()}
